@@ -10,7 +10,7 @@ use Rose::DB::Object::Metadata::UniqueKey;
 use Rose::DB::Object::Metadata::Auto;
 our @ISA = qw(Rose::DB::Object::Metadata::Auto);
 
-our $VERSION = '0.73';
+our $VERSION = '0.752';
 
 # syscolumns.coltype constants taken from:
 #
@@ -101,6 +101,14 @@ my %Datetime_Qualifiers =
   15 => 'fraction(5)',
 );
 
+my %Datetime_Qualifiers_Reverse = (reverse %Datetime_Qualifiers);
+
+# Value minus this delta = scale for fraction(n) types
+use constant FRACTION_SCALE_DELTA  => 10;
+
+use constant MIN_DATETIME_FRACTION => 11; # fraction(1)
+use constant MAX_DATETIME_FRACTION => 15; # fraction(5)
+
 # $INFORMIXDIR/etc/xpg4_is.sql
 # http://www-306.ibm.com/software/data/informix/pubs/library/datablade/dbdk/sqlr/01.fm50.html
 my %Numeric_Precision =
@@ -310,7 +318,7 @@ EOF
       elsif($type_num == DATETIME)
       {
         # Determine the full "datetime X to Y" type string
-        $type_name = _ix_datetime_specific_type($type_num, $sc_row->{'collength'});
+        $type_name = _ix_datetime_specific_type($self, $type_num, $sc_row->{'collength'}, $col_info);
       }
       else
       {
@@ -1100,17 +1108,17 @@ sub _ix_max_length
 #
 # The above is all just a fancy way of saying:
 #
-# largest_qualifier_value  = collength & 0xF0
+# largest_qualifier_value  = (collength & 0xF0) >> 4
 # smallest_qualifier_value = collength & 0xF
 #
 
 sub _ix_datetime_specific_type
 {
-  my($type_num, $collength) = @_;
+  my($meta, $type_num, $collength, $col_info) = @_;
 
   return  unless($type_num == DATETIME);
 
-  my $largest_qualifier  = $collength & 0xF0;
+  my $largest_qualifier  = ($collength & 0xF0) >> 4;
   my $smallest_qualifier = $collength & 0xF;
 
   unless(exists $Datetime_Qualifiers{$largest_qualifier} &&
@@ -1119,7 +1127,40 @@ sub _ix_datetime_specific_type
     die "No datetime qualifier(s) found for collength $collength";
   }
 
-  return "datetime $Datetime_Qualifiers{$largest_qualifier} to $Datetime_Qualifiers{$smallest_qualifier}";
+  # Handle DATETIME HOUR TO (MINUTE|SECOND|FRACTION(1-5)) as a "time" column.
+  if($largest_qualifier == $Datetime_Qualifiers_Reverse{'hour'} &&
+     ($smallest_qualifier == $Datetime_Qualifiers_Reverse{'minute'} ||
+      $smallest_qualifier == $Datetime_Qualifiers_Reverse{'second'} ||
+      ($smallest_qualifier >= MIN_DATETIME_FRACTION && 
+       $smallest_qualifier <= MAX_DATETIME_FRACTION)))
+  {
+    if($smallest_qualifier >= MIN_DATETIME_FRACTION && 
+       $smallest_qualifier <= MAX_DATETIME_FRACTION)
+    {
+      $col_info->{'TIME_SCALE'} = $smallest_qualifier - FRACTION_SCALE_DELTA;
+    }
+    else
+    {
+      delete $col_info->{'TIME_SCALE'};
+
+      if($smallest_qualifier == $Datetime_Qualifiers_Reverse{'minute'})
+      {
+        $col_info->{'TIME_PRECISION'} = 4; # HH:MM
+      }
+    }
+
+    return 'time';
+  }
+
+  my $type = "datetime $Datetime_Qualifiers{$largest_qualifier} to $Datetime_Qualifiers{$smallest_qualifier}";
+
+  # Punt on unsupported datetime column granularities
+  unless($meta->column_type_class($type))
+  {
+    return 'scalar';
+  }
+  
+  return $type;
 }
 
 1;
