@@ -112,6 +112,8 @@ sub perl_hash_definition
   my @delete_keys = grep { !$attrs{$_} } keys %hash;
   delete @hash{@delete_keys};
 
+  $hash{'column_map'} = delete $hash{'key_columns'}  if(exists $hash{'key_columns'});
+
   my $max_len = 0;
   my $min_len = -1;
 
@@ -214,6 +216,30 @@ sub perl_relationship_definition_attributes
   return @attrs;
 }
 
+sub object_has_related_objects
+{
+  my($self, $object) = @_;
+  
+  unless($object->isa($self->parent->class))
+  {
+    my $class = $self->parent->class;
+    Carp::croak "Cannot check for items related through the ", $self->name,
+                " relationship.  Object does not inherit from $class: $object";
+  }
+  
+  my $related_objects = $object->{$self->hash_key};
+  my $ref = ref $related_objects;
+
+  if($ref eq 'ARRAY' && @{$related_objects})
+  {
+    return $related_objects;
+  }
+
+  return $ref ? [ $related_objects ] : 0;
+}
+
+sub requires_preexisting_parent_object { } # override in subclass
+
 1;
 
 __END__
@@ -361,7 +387,7 @@ If any of the methods could not be created for any reason, a fatal error will oc
 
 =item B<methods MAP>
 
-Set the list of L<auto_method_types|/auto_method_types> and method names all at once.  MAP should be a reference to a hash whose keys are method types and whose values are either undef or method names.  If a value is undef, then the method name for that method type will be generated by calling B<build_method_name_for_type|/build_method_name_for_type>, as usual.  Otherwise, the specified method name will be used.
+Set the list of L<auto_method_types|/auto_method_types> and method names all at once.  MAP should be a reference to a hash whose keys are method types and whose values are either undef or method names.  If a value is undef, then the method name for that method type will be generated by calling L<build_method_name_for_type|/build_method_name_for_type>, as usual.  Otherwise, the specified method name will be used.
 
 =item B<method_types [TYPES]>
 
